==> twinlisp-0.3.1.tar.gz: twinlisp/core/PackDef.lisp <==
;Copyright (C) 2006 Mikalai Birukou
;
;This file is part of TwinLisp.
;
;    TwinLisp is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    TwinLisp is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with TwinLisp; if not, write to the Free Software
;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
;; TwinLisp package definition
(cl:defpackage TwinLisp (:nicknames "TWL" "TL") (:use "COMMON-LISP") (:export ; useful macros
 "NEW" "TL-CASE" "TL-FOR" "VAR" "PARAM" "CONST" "TL-TIMES" ; useful functions
 "CIN" "COUT" "TL-HOME-PATH" "TL-DIR-SEP" "TL-SET-HOME-PATH" "TL-LOAD" "TL-REQUIRE" "TRANSLATE" "TRANSLATE-STREAMS" "TRANSLATE-FILES" ; export operators' symbols
 "_UNARY+_" "_UNARY-_" "_NOT_" "_**_" "_*_" "_/_" "_%_" "_+_" "_-_" "_AND_" "_XOR_" "_OR_" "_<_" "_>_" "_<=_" "_>=_" "_==_" "_!=_" "_<<_" "_+=_" "_-=_" "_*=_" "_/=_" ; export universal methods
 "_COPY_" "_DEEPCOPY_" ; export types' symbols
 "_SLICE_" "_ITERATOR_" "_LIST-ITERATOR_" "_SEQUENCE-ITERATOR_" ; export container creation funcs
 "_MAKE-SLICE_" "_MAKE-HASH-TABLE_" "_MAKE-VECTOR_" ; export containers' methods
 "LEN" "_GETITEM_" "(SETF _GETITEM_)" "INDEX" "ITER" "EXTEND" "INSERT" "UPDATE" "TL-POP" "TL-COUNT" "TL-APPEND" "TL-REMOVE" "TKEYS" "TVALUES" "TITEMS" "HAS_KEY" ; export error conditions
 "INDEX-ERROR" "CONTAINER" ; "INDEX" is exported above
 "NULL-LIST-ERROR"))
(use-package "TL")
(cl:in-package "TWINLISP")
(defvar tl-home-folder-path cl:nil)
(defvar tl-directory-separator cl:nil)
(cl:defun tl-set-home-path (pathStr dirSep) (cl:cond ((not tl-home-folder-path) (cl:setf tl-home-folder-path pathStr))) (cl:cond ((not tl-directory-separator) (cl:setf tl-directory-separator dirSep))))
(cl:defun tl-home-path () (cl:cond (tl-home-folder-path tl-home-folder-path) (cl:t (error "Home directory is not set."))))
(cl:defun tl-dir-sep () (cl:cond (tl-directory-separator tl-directory-separator) (cl:t (error "Directory separator character is not set."))))

==> twinlisp-0.3.2.tar.gz: twinlisp/core/PackDef.lisp <==
;Copyright (C) 2006 Mikalai Birukou
;
;This file is part of TwinLisp.
;
;    TwinLisp is free software; you can redistribute it and/or modify
;    it under the terms of the GNU General Public License as published by
;    the Free Software Foundation; either version 2 of the License, or
;    (at your option) any later version.
;
;    TwinLisp is distributed in the hope that it will be useful,
;    but WITHOUT ANY WARRANTY; without even the implied warranty of
;    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;    GNU General Public License for more details.
;
;    You should have received a copy of the GNU General Public License
;    along with TwinLisp; if not, write to the Free Software
;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
;; TwinLisp package definition
(cl:defpackage TwinLisp (:nicknames "TWL" "TL") (:use "COMMON-LISP") (:export ; useful macros
 "NEW" "TL-CASE" "TL-FOR" "VAR" "PARAM" "CONST" "TL-TIMES" ; useful functions
 "CIN" "COUT" "TL-HOME-PATH" "TL-DIR-SEP" "TL-SET-HOME-PATH" "TL-LOAD" "TL-REQUIRE" "TRANSLATE" "TRANSLATE-STREAMS" "TRANSLATE-FILES" ; export operators' symbols
 "_UNARY+_" "_UNARY-_" "_NOT_" "_**_" "_*_" "_/_" "_%_" "_+_" "_-_" "_AND_" "_XOR_" "_OR_" "_<_" "_>_" "_<=_" "_>=_" "_==_" "_!=_" "_<<_" "_+=_" "_-=_" "_*=_" "_/=_" ; export universal methods
 "_COPY_" "_DEEPCOPY_" "_GETSTATE_" "_SETSTATE_" ; export types' symbols
 "_SLICE_" "_ITERATOR_" "_LIST-ITERATOR_" "_SEQUENCE-ITERATOR_" ; export container creation funcs
 "_MAKE-SLICE_" "_MAKE-HASH-TABLE_" "_MAKE-VECTOR_" ; export containers' methods
 "LEN" "_GETITEM_" "(SETF _GETITEM_)" "INDEX" "ITER" "EXTEND" "INSERT" "UPDATE" "TL-POP" "TL-COUNT" "TL-APPEND" "TL-REMOVE" "TKEYS" "TVALUES" "TITEMS" "HAS_KEY" ; export error conditions
 "INDEX-ERROR" "CONTAINER" ; "INDEX" is exported above
 "NULL-LIST-ERROR"))
(use-package "TL")
(cl:in-package "TWINLISP")
(defvar tl-home-folder-path cl:nil)
(defvar tl-directory-separator cl:nil)
(cl:defun tl-set-home-path (pathStr dirSep) (cl:cond ((not tl-home-folder-path) (cl:setf tl-home-folder-path pathStr))) (cl:cond ((not tl-directory-separator) (cl:setf tl-directory-separator dirSep))))
(cl:defun tl-home-path () (cl:cond (tl-home-folder-path tl-home-folder-path) (cl:t (error "Home directory is not set."))))
(cl:defun tl-dir-sep () (cl:cond (tl-directory-separator tl-directory-separator) (cl:t (error "Directory separator character is not set."))))
